===========
PandasTools
===========


.. image:: https://img.shields.io/pypi/v/pandastools.svg
        :target: https://pypi.python.org/pypi/pandastools

.. image:: https://img.shields.io/travis/phil65/PandasTools.svg
        :target: https://travis-ci.org/phil65/PandasTools

.. image:: https://readthedocs.org/projects/pandastools/badge/?version=latest
        :target: https://pandastools.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/phil65/PandasTools/shield.svg
     :target: https://pyup.io/repos/github/phil65/PandasTools/
     :alt: Updates



Helper functions for pandas


* Free software: MIT license
* Documentation: https://pandastools.readthedocs.io.


Features
--------

* TODO